@@ -25,7 +25,7 @@ from ravendb.exceptions.raven_exceptions import RavenException
 from ravendb.http.server_node import ServerNode
 from ravendb.http.raven_command import RavenCommand
 from ravendb.documents.operations.misc import GetOperationStateOperation
-from ravendb.documents.session.entity_to_json import EntityToJson
+from ravendb.documents.session.entity_to_json import EntityToJsonStatic
 from ravendb.documents.session.document_info import DocumentInfo
 from ravendb.json.metadata_as_dictionary import MetadataAsDictionary
 from ravendb.documents.commands.batches import CommandType
@@ -322,7 +322,7 @@ class BulkInsertOperation:
 
     def _write_document(self, entity: object, metadata: MetadataAsDictionary):
         document_info = DocumentInfo(metadata_instance=metadata)
-        json_dict = EntityToJson.convert_entity_to_json_internal_static(entity, self._conventions, document_info, True)
+        json_dict = EntityToJsonStatic.convert_entity_to_json(entity, self._conventions, document_info, True)
         self._current_data_buffer += bytearray(json.dumps(json_dict), encoding="utf-8")
 
     def _ensure_ongoing_operation(self) -> None:
@@ -413,9 +413,6 @@ class BulkInsertOperation:
         self._generate_entity_id_on_the_client.try_set_identity(entity, key)
         return key
 
-    # todo: CountersBulkInsert
-    # todo: CountersBulkInsertOperation
-
     class TimeSeriesBulkInsertBase(ABC):
         def __init__(self, operation: Optional[BulkInsertOperation], id_: Optional[str], name: Optional[str]):
             operation._end_previous_command_if_needed()
@@ -625,9 +622,13 @@ class BulkInsertOperation:
             self.operation = operation
 
         def store(self, key: str, name: str, attachment_bytes: bytes, content_type: Optional[str] = None):
-            self.operation._concurrency_check()
-            self.operation._end_previous_command_if_needed()
-            self.operation._ensure_ongoing_operation()
+            release_lock_callback = self.operation._concurrency_check()
+            try:
+                self.operation._end_previous_command_if_needed()
+                self.operation._ensure_ongoing_operation()
+            except Exception as e:
+                release_lock_callback()
+                raise e
 
             try:
                 if not self.operation._first:
@@ -655,6 +656,9 @@ class BulkInsertOperation:
             except Exception as e:
                 self.operation._handle_errors(key, e)
 
+            finally:
+                release_lock_callback()
+
     def attachments_for(self, key: str) -> BulkInsertOperation.AttachmentsBulkInsert:
         if not key or key.isspace():
             raise ValueError("Document id cannot be None or empty.")
