@@ -5,7 +5,7 @@ import threading
 from abc import abstractmethod, ABC
 from datetime import timedelta, datetime
 from enum import Enum
-from typing import Dict, List, Tuple, Callable, Union, Optional, Generic, Type
+from typing import Dict, List, Tuple, Callable, Union, Optional, Generic, Type, Any, TYPE_CHECKING
 
 import inflect
 
@@ -25,6 +25,11 @@ inflector = inflect.engine()
 
 _T = TypeVar("_T")
 
+if TYPE_CHECKING:
+    from ravendb.documents.session.document_session_operations.in_memory_document_session_operations import (
+        InMemoryDocumentSessionOperations,
+    )
+
 
 class DocumentConventions(object):
     @classmethod
@@ -32,6 +37,7 @@ class DocumentConventions(object):
         return cls()
 
     __cached_default_type_collection_names: Dict[type, str] = {}
+    __cached_keys_collection_names: Dict[str, str] = {}
 
     def __init__(self):
         self._frozen = False
@@ -62,12 +68,14 @@ class DocumentConventions(object):
 
         # Utilities
         self.document_id_generator: Optional[Callable[[str, object], str]] = None
-        self._find_identity_property = lambda q: q.__name__ == "key"
+        self._find_identity_property_name: Callable[[Type[Any]], str] = lambda type_: "Id"
+        self._id_property_name_cache: Dict[Type, str] = {}
         self._find_python_class: Optional[Callable[[str, Dict], str]] = None
         self._find_collection_name: Callable[[Type], str] = self.default_get_collection_name
-        self._find_python_class_name: Callable[
-            [Type], str
-        ] = lambda object_type: f"{object_type.__module__}.{object_type.__name__}"
+        self._find_collection_name_for_dict: Callable[[str], str] = self.default_get_collection_name_for_dict
+        self._find_python_class_name: Callable[[Type], str] = (
+            lambda object_type: f"{object_type.__module__}.{object_type.__name__}"
+        )
         self._transform_class_collection_name_to_document_id_prefix = (
             lambda collection_name: self.default_transform_collection_name_to_document_id_prefix(collection_name)
         )
@@ -104,7 +112,7 @@ class DocumentConventions(object):
 
     @find_collection_name.setter
     def find_collection_name(self, value) -> None:
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._find_collection_name = value
 
     @property
@@ -120,7 +128,7 @@ class DocumentConventions(object):
 
     @find_python_class.setter
     def find_python_class(self, value: Callable[[str, Dict], str]):
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._find_python_class = value
 
     def get_python_class(self, key: str, document: Dict) -> str:
@@ -132,7 +140,7 @@ class DocumentConventions(object):
 
     @transform_class_collection_name_to_document_id_prefix.setter
     def transform_class_collection_name_to_document_id_prefix(self, value: Callable[[str], str]) -> None:
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._transform_class_collection_name_to_document_id_prefix = value
 
     @property
@@ -165,7 +173,7 @@ class DocumentConventions(object):
 
     @find_python_class_name.setter
     def find_python_class_name(self, value) -> None:
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._find_python_class_name = value
 
     @property
@@ -174,7 +182,7 @@ class DocumentConventions(object):
 
     @should_ignore_entity_changes.setter
     def should_ignore_entity_changes(self, value: ShouldIgnoreEntityChanges) -> None:
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._should_ignore_entity_changes = value
 
     @property
@@ -183,7 +191,7 @@ class DocumentConventions(object):
 
     @load_balancer_context_seed.setter
     def load_balancer_context_seed(self, value: int):
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._load_balancer_context_seed = value
 
     @property
@@ -192,7 +200,7 @@ class DocumentConventions(object):
 
     @load_balance_behavior.setter
     def load_balance_behavior(self, value: LoadBalanceBehavior):
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._load_balance_behavior = value
 
     @property
@@ -201,7 +209,7 @@ class DocumentConventions(object):
 
     @read_balance_behavior.setter
     def read_balance_behavior(self, value: ReadBalanceBehavior):
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._read_balance_behavior = value
 
     @property
@@ -214,9 +222,17 @@ class DocumentConventions(object):
 
     @disable_atomic_document_writes_in_cluster_wide_transaction.setter
     def disable_atomic_document_writes_in_cluster_wide_transaction(self, value: bool):
-        self.__assert_not_frozen()
+        self._assert_not_frozen()
         self._disable_atomic_document_writes_in_cluster_wide_transaction = value
 
+    @property
+    def find_identity_property_name(self) -> Callable[[Type[Any]], str]:
+        return self._find_identity_property_name
+
+    @find_identity_property_name.setter
+    def find_identity_property_name(self, find_identity_property_name_function: Callable[[Type[Any]], str]):
+        self._find_identity_property_name = find_identity_property_name_function
+
     @staticmethod
     def json_default(o):
         if o is None:
@@ -281,6 +297,13 @@ class DocumentConventions(object):
 
         return self.default_get_collection_name(object_type)
 
+    def get_collection_name_for_dict(self, key: str):
+        collection = key.split("/")[0]
+        collection_name = self._find_collection_name_for_dict(collection)
+        if collection_name:
+            return collection_name
+        return self.default_get_collection_name(dict)
+
     def generate_document_id(self, database_name: str, entity: object) -> str:
         object_type = type(entity)
         for list_of_registered_id_convention in self._list_of_registered_id_conventions:
@@ -306,7 +329,17 @@ class DocumentConventions(object):
         return result
 
     @staticmethod
-    def try_get_type_from_metadata(metadata):
+    def default_get_collection_name_for_dict(key: str) -> str:
+        result = DocumentConventions.__cached_keys_collection_names.get(key, None)
+        if result:
+            return result
+        # singular_noun returns False if the word is singular
+        result = inflector.plural(key) if not inflector.singular_noun(key) else key
+        DocumentConventions.__cached_keys_collection_names[key] = result
+        return result
+
+    @staticmethod
+    def try_get_type_from_metadata(metadata: Dict[str, Any]) -> Optional[str]:
         if "Raven-Python-Type" in metadata:
             return metadata["Raven-Python-Type"]
         return None
@@ -336,7 +369,7 @@ class DocumentConventions(object):
 
         return field_name
 
-    def __assert_not_frozen(self) -> None:
+    def _assert_not_frozen(self) -> None:
         if self._frozen:
             raise RuntimeError(
                 "Conventions has been frozen after documentStore.initialize()" " and no changes can be applied to them"
@@ -351,7 +384,7 @@ class DocumentConventions(object):
         cloned._save_enums_as_integers = self._save_enums_as_integers
         cloned.identity_parts_separator = self.identity_parts_separator
         cloned.disable_topology_updates = self.disable_topology_updates
-        cloned._find_identity_property = self._find_identity_property
+        cloned._find_identity_property_name = self._find_identity_property_name
 
         cloned.document_id_generator = self.document_id_generator
 
@@ -365,6 +398,19 @@ class DocumentConventions(object):
         cloned._read_balance_behavior = self._read_balance_behavior
         cloned._load_balance_behavior = self._load_balance_behavior
         self._max_http_cache_size = self._max_http_cache_size
+        return cloned
+
+    def get_identity_property_name(self, object_type: Type[Any]) -> Optional[str]:
+        # Check the cache first
+        if object_type in self._id_property_name_cache:
+            return self._id_property_name_cache[object_type]
+
+        id_property_name = self.find_identity_property_name(object_type)
+
+        # Cache the result
+        self._id_property_name_cache[object_type] = id_property_name
+
+        return id_property_name
 
     def update_from(self, configuration: ClientConfiguration):
         if configuration.disabled and self._original_configuration is None:
@@ -460,7 +506,7 @@ class DocumentConventions(object):
 
     @staticmethod
     def default_transform_collection_name_to_document_id_prefix(collection_name: str) -> str:
-        upper_count = len(list(filter(str.isupper, collection_name)))
+        upper_count = len(list(filter(str.isupper, [char for char in collection_name])))
         if upper_count <= 1:
             return collection_name.lower()
 
