@@ -3,7 +3,7 @@ from __future__ import annotations
 import http
 from typing import Union, Optional, TYPE_CHECKING, TypeVar
 
-from ravendb.documents.session.entity_to_json import EntityToJson
+from ravendb.documents.session.entity_to_json import EntityToJsonStatic
 from ravendb.documents.operations.patch import PatchOperation, PatchStatus
 from ravendb.documents.operations.definitions import (
     IOperation,
@@ -25,7 +25,7 @@ if TYPE_CHECKING:
 
 
 _T = TypeVar("_T")
-_Operation_T = TypeVar("_Operation_T")
+_T_Operation_Return = TypeVar("_T_Operation_Return")
 
 
 class OperationExecutor:
@@ -41,7 +41,7 @@ class OperationExecutor:
             return self
         return OperationExecutor(self._store, database_name)
 
-    def send(self, operation: IOperation[_Operation_T], session_info: SessionInfo = None) -> _Operation_T:
+    def send(self, operation: IOperation[_T_Operation_Return], session_info: SessionInfo = None) -> _T_Operation_Return:
         command = operation.get_command(self._store, self._request_executor.conventions, self._request_executor.cache)
         self._request_executor.execute_command(command, session_info)
         return None if isinstance(operation, VoidOperation) else command.result
@@ -90,7 +90,7 @@ class OperationExecutor:
 
         try:
             result.status = command.result.status
-            result.document = EntityToJson.convert_to_entity_static(
+            result.document = EntityToJsonStatic.convert_to_entity(
                 command.result.modified_document, entity_class, self._request_executor.conventions
             )
             return result
@@ -126,7 +126,7 @@ class MaintenanceOperationExecutor:
     def server(self) -> ServerOperationExecutor:
         if self._server_operation_executor is not None:
             return self._server_operation_executor
-        self._server_operation_executor = ServerOperationExecutor(self._store)
+        self._server_operation_executor = ServerOperationExecutor.from_store(self._store)
         return self._server_operation_executor
 
     def for_database(self, database_name: str) -> MaintenanceOperationExecutor:
@@ -136,8 +136,8 @@ class MaintenanceOperationExecutor:
         return MaintenanceOperationExecutor(self._store, database_name)
 
     def send(
-        self, operation: Union[VoidMaintenanceOperation, MaintenanceOperation[_Operation_T]]
-    ) -> Optional[_Operation_T]:
+        self, operation: Union[VoidMaintenanceOperation, MaintenanceOperation[_T_Operation_Return]]
+    ) -> Optional[_T_Operation_Return]:
         self._assert_database_name_set()
         command = operation.get_command(self.request_executor.conventions)
         self.request_executor.execute_command(command)
