@@ -1,26 +1,32 @@
 from __future__ import annotations
-import enum
 import json
-from typing import List, TYPE_CHECKING
+from typing import List, TYPE_CHECKING, Optional, Tuple
 
 import requests
 
 from ravendb.exceptions import exceptions
 from ravendb.exceptions.exceptions import ErrorResponseException
-from ravendb.documents.indexes.definitions import IndexDefinition, IndexErrors, IndexLockMode, IndexPriority
+from ravendb.documents.indexes.definitions import (
+    IndexDefinition,
+    IndexErrors,
+    IndexLockMode,
+    IndexPriority,
+    IndexRunningStatus,
+)
 from ravendb.documents.operations.definitions import MaintenanceOperation, VoidMaintenanceOperation
 from ravendb.http.raven_command import RavenCommand, VoidRavenCommand
 from ravendb.http.server_node import ServerNode
 from ravendb.http.topology import RaftCommand
 from ravendb.tools.utils import Utils
 from ravendb.util.util import RaftIdGenerator
+from ravendb.documents.indexes.stats import IndexStats
 
 if TYPE_CHECKING:
     from ravendb.documents.conventions import DocumentConventions
 
 
 class PutIndexesOperation(MaintenanceOperation):
-    def __init__(self, *indexes_to_add):
+    def __init__(self, *indexes_to_add: IndexDefinition):
         if len(indexes_to_add) == 0:
             raise ValueError("Invalid indexes_to_add")
 
@@ -29,10 +35,10 @@ class PutIndexesOperation(MaintenanceOperation):
         self.__all_java_script_indexes = True  # todo: set it in the command
 
     def get_command(self, conventions: "DocumentConventions") -> RavenCommand[List]:
-        return self.__PutIndexesCommand(conventions, *self._indexes_to_add)
+        return self.__PutIndexesCommand(conventions, self._indexes_to_add)
 
     class __PutIndexesCommand(RavenCommand[List], RaftCommand):
-        def __init__(self, conventions: "DocumentConventions", *index_to_add):
+        def __init__(self, conventions: "DocumentConventions", index_to_add: Tuple[IndexDefinition]):
             super().__init__(list)
             if conventions is None:
                 raise ValueError("Conventions cannot be None")
@@ -270,13 +276,6 @@ class StopIndexOperation(VoidMaintenanceOperation):
             )
 
 
-class IndexRunningStatus(enum.Enum):
-    RUNNING = "Running"
-    PAUSED = "Paused"
-    DISABLED = "Disabled"
-    PENDING = "Pending"
-
-
 class IndexStatus:
     def __init__(self, name: str = None, status: IndexRunningStatus = None):
         self.name = name
@@ -288,9 +287,7 @@ class IndexStatus:
 
 
 class IndexingStatus:
-    def __init__(
-        self, status: IndexRunningStatus = None, indexes: List[IndexStatus] = None
-    ):  # todo: Optional typehints
+    def __init__(self, status: IndexRunningStatus = None, indexes: List[IndexStatus] = None):
         self.status = status
         self.indexes = indexes
 
@@ -325,17 +322,17 @@ class GetIndexingStatusOperation(MaintenanceOperation[IndexingStatus]):
             self.result = IndexingStatus.from_json(response)
 
 
-class GetIndexStatisticsOperation(MaintenanceOperation[dict]):  # replace returned type with IndexStats -> its enormous
+class GetIndexStatisticsOperation(MaintenanceOperation["IndexStats"]):
     def __init__(self, name):
         if name is None:
             raise ValueError("Index name cannot be None")
         super().__init__()
         self.__index_name = name
 
-    def get_command(self, conventions) -> RavenCommand[dict]:
-        return self.__GetIndexStatisticsCommand(self.__index_name)
+    def get_command(self, conventions) -> RavenCommand["IndexStats"]:
+        return self._GetIndexStatisticsCommand(self.__index_name)
 
-    class __GetIndexStatisticsCommand(RavenCommand[dict]):
+    class _GetIndexStatisticsCommand(RavenCommand["IndexStats"]):
         def __init__(self, index_name: str):
             if not index_name:
                 raise ValueError("Index name can't be None or empty")
@@ -343,10 +340,10 @@ class GetIndexStatisticsOperation(MaintenanceOperation[dict]):  # replace return
             self.__index_name = index_name
 
         def create_request(self, server_node) -> requests.Request:
+            url = f"{server_node.url}/databases/{server_node.database}/indexes/stats?name={Utils.quote_key(self.__index_name)}"
             return requests.Request(
                 "GET",
-                f"{server_node.url}/databases/{server_node.database}"
-                f"/indexes/stats?name={Utils.escape(self.__index_name, False, False)}",
+                url,
             )
 
         def is_read_request(self) -> bool:
@@ -354,14 +351,15 @@ class GetIndexStatisticsOperation(MaintenanceOperation[dict]):  # replace return
 
         def set_response(self, response: str, from_cache: bool) -> None:
             if response is None:
-                raise ValueError("Invalid response")
+                self._throw_invalid_response()
 
             response = json.loads(response)
-            if "Error" in response:
-                raise exceptions.ErrorResponseException(response["Error"])
-            if "Results" not in response or len(response["Results"]) > 1:
-                raise ValueError("Invalid response")
-            self.result = response["Results"]
+            results = response["Results"]
+
+            if len(results) != 1:
+                self._throw_invalid_response()
+
+            self.result = IndexStats.from_json(results[0])
 
 
 class GetIndexesStatisticsOperation(
@@ -556,7 +554,7 @@ class SetIndexesPriorityOperation(VoidMaintenanceOperation):
 
 
 class GetTermsOperation(MaintenanceOperation[List[str]]):
-    def __init__(self, index_name: str, field: str, from_value: str, page_size: int = None):
+    def __init__(self, index_name: str, field: str, from_value: Optional[str], page_size: int = None):
         if index_name is None:
             raise ValueError("Index name cannot be None")
         if field is None:
@@ -584,8 +582,8 @@ class GetTermsOperation(MaintenanceOperation[List[str]]):
                 f"{server_node.url}/databases/{server_node.database}"
                 f"/indexes/terms?name={Utils.escape(self.__index_name, False, False)}"
                 f"&field={Utils.escape(self.__field, False, False)}"
-                f"&fromValue={self.__from_value if self.__from_value is not None else ''}"
-                f"&pageSize={self.__page_size if self.__page_size is not None else ''}",
+                f"&fromValue={self.__from_value or ''}"
+                f"&pageSize={self.__page_size or ''}",
             )
 
         def set_response(self, response: str, from_cache: bool) -> None:
@@ -635,3 +633,51 @@ class IndexHasChangedOperation(MaintenanceOperation[bool]):
                 raise ValueError("Response is invalid")
 
             self.result = json.loads(response)["Changed"]
+
+
+class ResetIndexOperation(VoidMaintenanceOperation):
+    def __init__(self, index_name: str):
+        if index_name is None:
+            raise ValueError("Index name cannot be None")
+
+        self._index_name = index_name
+
+    def get_command(self, conventions: "DocumentConventions") -> "VoidRavenCommand":
+        return ResetIndexOperation.ResetIndexCommand(self._index_name)
+
+    class ResetIndexCommand(VoidRavenCommand):
+        def __init__(self, index_name: str):
+            super().__init__()
+            if index_name is None:
+                raise ValueError("Index name cannot be None")
+
+            self._index_name = index_name
+
+        def create_request(self, node: ServerNode) -> requests.Request:
+            return requests.Request("RESET", f"{node.url}/databases/{node.database}/indexes?name={self._index_name}")
+
+
+class DeleteIndexErrorsOperation(VoidMaintenanceOperation):
+    def __init__(self, index_names: List[str] = None):
+        self._index_names = index_names
+
+    def get_command(self, conventions: "DocumentConventions") -> "VoidRavenCommand":
+        return self.DeleteIndexErrorsCommand(self._index_names)
+
+    class DeleteIndexErrorsCommand(VoidRavenCommand):
+        def __init__(self, index_names: List[str]):
+            super().__init__()
+            self._index_names = index_names
+
+        def create_request(self, node: ServerNode) -> requests.Request:
+            url = f"{node.url}/databases/{node.database}/indexes/errors"
+
+            if self._index_names is not None and len(self._index_names) > 0:
+                url = f"{url}?"
+                for index_name in self._index_names:
+                    url = f"{url}&name={Utils.quote_key(index_name)}"
+
+            return requests.Request("DELETE", url)
+
+        def is_read_request(self) -> bool:
+            return False
