@@ -7,6 +7,7 @@ import logging
 import os
 from concurrent.futures import ThreadPoolExecutor, Future, FIRST_COMPLETED, wait, ALL_COMPLETED
 import uuid
+from json import JSONDecodeError
 from threading import Timer, Semaphore, Lock
 
 import requests
@@ -47,7 +48,7 @@ if TYPE_CHECKING:
 class RequestExecutor:
     __INITIAL_TOPOLOGY_ETAG = -2
     __GLOBAL_APPLICATION_IDENTIFIER = uuid.uuid4()
-    CLIENT_VERSION = "5.2.5"
+    CLIENT_VERSION = "7.1.2"
     logger = logging.getLogger("request_executor")
 
     # todo: initializer should take also cryptography certificates
@@ -93,12 +94,12 @@ class RequestExecutor:
 
         self.__http_session: Union[None, requests.Session] = None
 
-        self.first_broadcast_attempt_timeout: Union[
-            None, datetime.timedelta
-        ] = conventions.first_broadcast_attempt_timeout
-        self.second_broadcast_attempt_timeout: Union[
-            None, datetime.timedelta
-        ] = conventions.second_broadcast_attempt_timeout
+        self.first_broadcast_attempt_timeout: Union[None, datetime.timedelta] = (
+            conventions.first_broadcast_attempt_timeout
+        )
+        self.second_broadcast_attempt_timeout: Union[None, datetime.timedelta] = (
+            conventions.second_broadcast_attempt_timeout
+        )
 
         self._first_topology_update_task: Union[None, Future] = None
         self._last_known_urls: Union[None, List[str]] = None
@@ -129,7 +130,8 @@ class RequestExecutor:
             self.__update_topology_timer.cancel()
 
         self._dispose_all_failed_nodes_timers()
-        self.__http_session.close()
+        if self.__http_session is not None:
+            self.__http_session.close()
 
     @property
     def certificate_path(self) -> str:
@@ -169,7 +171,6 @@ class RequestExecutor:
         return self.__http_session
 
     def __create_http_session(self) -> requests.Session:
-        # todo: check if http client name is required
         session = requests.session()
         session.cert = self.__certificate_path
         session.verify = self.__trust_store_path if self.__trust_store_path else True
@@ -197,11 +198,11 @@ class RequestExecutor:
 
     @property
     def preferred_node(self) -> CurrentIndexAndNode:
-        self.__ensure_node_selector()
+        self._ensure_node_selector()
         return self._node_selector.get_preferred_node()
 
     def get_requested_node(self, node_tag: str, throw_if_contains_failures: bool = False) -> CurrentIndexAndNode:
-        self.__ensure_node_selector()
+        self._ensure_node_selector()
         current_index_and_node = self._node_selector.get_requested_node(node_tag)
 
         if throw_if_contains_failures and not self._node_selector.node_is_available(
@@ -213,6 +214,16 @@ class RequestExecutor:
 
         return current_index_and_node
 
+    def get_fastest_node(self) -> CurrentIndexAndNode:
+        self._ensure_node_selector()
+
+        return self._node_selector.get_fastest_node()
+
+    def get_node_by_session_id(self, session_id: int = None) -> CurrentIndexAndNode:
+        self._ensure_node_selector()
+
+        return self._node_selector.get_node_by_session_id(session_id)
+
     def __on_failed_request_invoke(self, url: str, e: Exception):
         for event in self.__on_failed_request:
             event(FailedRequestEventArgs(self._database_name, url, e, None, None))
@@ -428,9 +439,11 @@ class RequestExecutor:
 
             topology = Topology(
                 self._topology_etag,
-                self.topology_nodes
-                if self.topology_nodes
-                else list(map(lambda url_val: ServerNode(url_val, self._database_name, "!"), initial_urls)),
+                (
+                    self.topology_nodes
+                    if self.topology_nodes
+                    else list(map(lambda url_val: ServerNode(url_val, self._database_name, "!"), initial_urls))
+                ),
             )
 
             self._node_selector = NodeSelector(topology, self._thread_pool_executor)
@@ -894,7 +907,10 @@ class RequestExecutor:
         request = command.create_request(node)
         # todo: optimize that if - look for the way to make less ifs each time
         if request.data and not isinstance(request.data, str) and not inspect.isgenerator(request.data):
-            request.data = json.dumps(request.data, default=self.conventions.json_default_method)
+            # Making sur that all documents are utf-8 decoded, avoiding any bizzar caracters in the database documents
+            request.data = json.dumps(
+                request.data, default=self.conventions.json_default_method, ensure_ascii=False
+            ).encode("utf-8")
 
         # todo: 1117 - 1133
         return request or None
@@ -1091,9 +1107,10 @@ class RequestExecutor:
             return True
         else:
             command.on_response_failure(response)
-            raise RuntimeError(
-                json.loads(response.text).get("Message", "Missing message")
-            )  # todo: Exception dispatcher
+            try:  # todo: exception dispatcher
+                raise RuntimeError(json.loads(response.text).get("Message", "Missing message"))
+            except JSONDecodeError as e:
+                raise RuntimeError(f"Failed to parse response: {response.text}") from e
 
         return False
 
@@ -1227,7 +1244,7 @@ class RequestExecutor:
     def client_configuration_etag(self, value):
         self._client_configuration_etag = value
 
-    def __ensure_node_selector(self) -> None:
+    def _ensure_node_selector(self) -> None:
         if not self._disable_topology_updates:
             self.__wait_for_topology_update(self._first_topology_update_task)
 
