@@ -12,7 +12,7 @@ from ravendb.documents.indexes.definitions import (
 )
 from ravendb.documents.operations.backups.settings import PeriodicBackupConfiguration
 from ravendb.documents.operations.etl.configuration import RavenConnectionString, RavenEtlConfiguration
-from ravendb.documents.operations.etl.olap import OlapConnectionString, OlapEtlConfiguration
+from ravendb.documents.operations.etl.olap.connection import OlapConnectionString, OlapEtlConfiguration
 from ravendb.documents.operations.etl.sql import SqlConnectionString, SqlEtlConfiguration
 from ravendb.documents.operations.expiration.configuration import ExpirationConfiguration
 from ravendb.documents.operations.refresh.configuration import RefreshConfiguration
@@ -97,9 +97,11 @@ class DatabaseRecord:
             "Analyzers": self.analyzers,
             "Indexes": self.indexes,
             "IndexesHistory": self.indexes_history_story,
-            "AutoIndexes": {key: AutoIndexDefinition.to_json(auto_index) for key, auto_index in self.auto_indexes}
-            if self.auto_indexes
-            else None,
+            "AutoIndexes": (
+                {key: AutoIndexDefinition.to_json(auto_index) for key, auto_index in self.auto_indexes}
+                if self.auto_indexes
+                else None
+            ),
             "Settings": self.settings,
             "Revisions": self.revisions,
             "TimeSeries": self.time_series,
