@@ -244,7 +244,7 @@ class CaseInsensitiveSet(set):
             self.add(v)
 
 
-class _DynamicStructure(object):
+class DynamicStructure(object):
     def __init__(self, **entries):
         self.__dict__.update(entries)
 
@@ -346,7 +346,7 @@ class Utils(object):
 
         for item in items:
             if Utils.check_if_collection_but_not_str(item):
-                results.extend(Utils.__unpack_collection(item))
+                results.extend(Utils.unpack_collection(item))
                 continue
             results.append(item)
 
@@ -402,7 +402,7 @@ class Utils(object):
             return header[1 : len(header) - 2]
 
     @staticmethod
-    def import_class(name) -> Type:
+    def import_class(name) -> Optional[Type]:
         components = name.split(".")
         module_name = ".".join(name.split(".")[:-1])
         mod = None
@@ -450,7 +450,16 @@ class Utils(object):
     @staticmethod
     def initialize_object(obj: dict, object_type: Type[_T], convert_to_snake_case: bool = None) -> _T:
         initialize_dict, set_needed = Utils.make_initialize_dict(obj, object_type.__init__, convert_to_snake_case)
-        o = object_type(**initialize_dict)
+        try:
+            o = object_type(**initialize_dict)
+        except Exception as e:
+            if "Id" not in initialize_dict:
+                initialize_dict["Id"] = None
+                o = object_type(**initialize_dict)
+            else:
+                raise TypeError(
+                    f"Couldn't initialize object of type '{object_type.__name__}' using dict '{initialize_dict}'"
+                ) from e
         if set_needed:
             for key, value in obj.items():
                 setattr(o, key, value)
@@ -475,17 +484,17 @@ class Utils(object):
     @staticmethod
     def convert_json_dict_to_object(
         json_dict: dict, object_type: Optional[Type[_T]] = None, nested_object_types: Optional[Dict[str, type]] = None
-    ) -> Union[_DynamicStructure, _T]:
+    ) -> Union[DynamicStructure, _T]:
         if object_type == dict:
             return json_dict
 
         if object_type is None:
-            return _DynamicStructure(**json_dict)
+            return DynamicStructure(**json_dict)
 
         if nested_object_types is None:
             return Utils.initialize_object(json_dict, object_type, True)
 
-        entity = _DynamicStructure(**json_dict)
+        entity = DynamicStructure(**json_dict)
         entity.__class__ = object_type
         entity = Utils.initialize_object(json_dict, object_type, True)
         if nested_object_types:
@@ -537,7 +546,7 @@ class Utils(object):
         conventions: "DocumentConventions",
         events,
         nested_object_types=None,
-    ) -> Union[_T, _DynamicStructure]:
+    ) -> Union[_T, DynamicStructure]:
         if document is None:
             return None
         metadata = document.get("@metadata")
@@ -555,7 +564,7 @@ class Utils(object):
             if object_type is not None:
                 metadata["Raven-Python-Type"] = "{0}.{1}".format(object_type.__module__, object_type.__name__)
             else:  # no type defined on document or during load, return a dict
-                dyn = _DynamicStructure(**document)
+                dyn = DynamicStructure(**document)
                 events.after_conversion_to_entity(dyn, document, metadata)
                 return dyn, metadata, original_document
         else:
@@ -576,7 +585,7 @@ class Utils(object):
         if nested_object_types is None and mapper:
             entity = create_entity_with_mapper(document, mapper, object_type)
         else:
-            entity = _DynamicStructure(**document)
+            entity = DynamicStructure(**document)
             entity.__class__ = object_type
 
             entity = Utils.initialize_object(document, object_type)
@@ -602,9 +611,9 @@ class Utils(object):
                 converted_document = {}
                 for key in document:
                     converted_key = convert_to_snake_case.get(key, key)
-                    converted_document[
-                        converted_key if key == "Id" else Utils.convert_to_snake_case(converted_key)
-                    ] = document[key]
+                    converted_document[converted_key if key == "Id" else Utils.convert_to_snake_case(converted_key)] = (
+                        document[key]
+                    )
                 document = converted_document
             except:
                 pass
@@ -656,9 +665,7 @@ class Utils(object):
         return (
             datetime_obj.strftime(f"%Y-%m-%dT%H:%M:%S.%f{add_suffix}")
             if datetime_obj
-            else None
-            if return_none_if_none
-            else ""
+            else None if return_none_if_none else ""
         )
 
     @staticmethod
